Module id

Module id 

This module contains types relating to flix media IDs

Type Aliases

CollectionId
Type alias for a collection ID
LibraryId
Type alias for a library ID
MovieId
Type alias for a movie ID
RawId
Type alias for the raw ID representation The internal representation used by the database
ShowId
Type alias for a show ID