This module contains types relating to flix media IDs
Type Aliases
- Collection
Id - Type alias for a collection ID
- Library
Id - Type alias for a library ID
- MovieId
- Type alias for a movie ID
- RawId
- Type alias for the raw ID representation The internal representation used by the database
- ShowId
- Type alias for a show ID